@@ -285,7 +285,11 @@ class VarVault(object):
 
     def _vaulter__build_input_var_keys(self, input_keys, kwargs, *flags):
         mini = self.get_multiple(input_keys, *flags)
-        assert len(input_keys) == len(mini)
+
+        assert len(input_keys) == len(mini) or VaultFlags.flag_is_set(VaultFlags.input_key_can_be_missing(), *flags), \
+            f"The number of items acquired from {self.get_multiple.__name__} is not the same as the number of input-keys to the method, " \
+            f"and {VaultFlags.input_key_can_be_missing()} is not set. This is probably a bug."
+
         for key, value in mini.items():
             assert key not in kwargs, f"Key {key} seems to already exist in kwargs used for the function decorated with '@{self.vaulter.__name__}'"
 
@@ -437,7 +441,7 @@ class VarVault(object):
                     assert key in self, f"Key {key} is not mapped to an object in the vault; it appears to be missing in the vault. " \
                                         f"You can set the flag '{VaultFlags.input_key_can_be_missing()}' to avoid this, " \
                                         f"in which case the value will be {None}, or make sure a value is mapped to it."
-            [mini.update({key: self.vault.get(key)}) for key in keys]
+            [mini.update({key: self.vault.get(key)}) for key in keys if key in self]
             self._reset_log_levels()
         return mini
 
